==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/bedrockmodel/kotlin/outputs/InvocationLoggingConfigurationLoggingConfigCloudwatchConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.bedrockmodel.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property largeDataDeliveryS3Config S3 configuration for delivering a large amount of data. See `s3_config`.
 * @property logGroupName Log group name.
 * @property roleArn IAM Role ARN.
 * The following arguments are optional:
 */
public data class InvocationLoggingConfigurationLoggingConfigCloudwatchConfig(
    public val largeDataDeliveryS3Config:
    InvocationLoggingConfigurationLoggingConfigCloudwatchConfigLargeDataDeliveryS3Config? = null,
    public val logGroupName: String? = null,
    public val roleArn: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.bedrockmodel.outputs.InvocationLoggingConfigurationLoggingConfigCloudwatchConfig):
            InvocationLoggingConfigurationLoggingConfigCloudwatchConfig =
            InvocationLoggingConfigurationLoggingConfigCloudwatchConfig(
                largeDataDeliveryS3Config = javaType.largeDataDeliveryS3Config().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.bedrockmodel.kotlin.outputs.InvocationLoggingConfigurationLoggingConfigCloudwatchConfigLargeDataDeliveryS3Config.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                logGroupName = javaType.logGroupName().map({ args0 -> args0 }).orElse(null),
                roleArn = javaType.roleArn().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/bedrockmodel/kotlin/outputs/InvocationLoggingConfigurationLoggingConfigCloudwatchConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.bedrockmodel.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property largeDataDeliveryS3Config S3 configuration for delivering a large amount of data.
 * @property logGroupName Log group name.
 * @property roleArn The role ARN.
 */
public data class InvocationLoggingConfigurationLoggingConfigCloudwatchConfig(
    public val largeDataDeliveryS3Config: InvocationLoggingConfigurationLoggingConfigCloudwatchConfigLargeDataDeliveryS3Config? = null,
    public val logGroupName: String? = null,
    public val roleArn: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.bedrockmodel.outputs.InvocationLoggingConfigurationLoggingConfigCloudwatchConfig): InvocationLoggingConfigurationLoggingConfigCloudwatchConfig =
            InvocationLoggingConfigurationLoggingConfigCloudwatchConfig(
                largeDataDeliveryS3Config = javaType.largeDataDeliveryS3Config().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.bedrockmodel.kotlin.outputs.InvocationLoggingConfigurationLoggingConfigCloudwatchConfigLargeDataDeliveryS3Config.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                logGroupName = javaType.logGroupName().map({ args0 -> args0 }).orElse(null),
                roleArn = javaType.roleArn().map({ args0 -> args0 }).orElse(null),
            )
    }
}
